import { TransformOptions } from '@babel/core';
import { Env } from './types';
/**
 * 📝 Babel configurations
 *
 * - Project wide configuration file type `babel.config.js` used to set the
 *   "root" configurations. This is required for any project that needs to
 *   transform a linked npm package.
 * - Configs are specified by environment to make it easier to understand how
 *   each env is transformed.
 * - Only polyfills required for application code are added with the `usage`
 *   option of the preset-env `useBuiltIns`, but this does assume that libraries
 *   have properly handled compiling their polyfills.
 * - Under the hood calling `api.env` will enable caching based on NODE_ENV
 *
 * 📝 Core JS
 *
 * CoreJS includes the polyfills for new language features compiled by Babel.
 * The recommendation for polyfilling is to include the complete set of
 * polyfills needed for the target environment (vs only including polyfills used
 * in app code with `useBuiltIns: 'usage'`). Many libraries will transpile their
 * code but do not polyfill, and it's hard to tell whether polyfills are needed
 * in evergreen browsers because they don't need any.
 *
 * To completely polyfill for target envs, best practice is to use polyfill.io
 * for projects that can experience downtime, and to bundle polyfills with
 * preset-env for projects with critical uptimes.
 *
 * To polyfill with preset-env, set `useBuiltIns` to `entry` and import the
 * core-js and regenerator-runtime packages first in the application entry.
 * Preset env will transform them to just the polyfills needed to match the
 * targets environment. Explicitly set the `core-js` version used by
 * `preset-env` per Babel best practices.
 * - Polyfills are big, around 46.6kb for the `defaults` env target!
 * - For applications that need a guarantee for polyfilling, set the
 * - Optionally experimental features can be polyfilled by setting corejs to:
 *   { version: 3, proposals: true } (don't)
 * - Optionally the transform-runtime plugin accepts a `corejs` configuration
 *   option that will use imports from core-js to polyfill language features
 *   instead of adding polyfills to global scope (this is preferred for package
 *   compilation) Note that enabling this requires adding `@babel/runtime-corejs3`
 *   as a dependency.
 */
export default function reactConfigs(env: Env): TransformOptions;
